# Topsis Package
This easy to use package helps you to easily calculate the topsis score and the rank based on it for a given .csv data without the knowledge of the deep calculation employed behind it. The user can run this package through the command line and get the output in the form of a .csv file.

## Installation
To install the package , run the following command in command line.

```pip install Topsis-Manan-101903311 ```

## How to use it?
This package can be accessed through the command line. The user needs to run the command as follows

```Topsis input.csv weights impacts output.csv```

## License

2022 Manan Ghai

This repository is licensed under the MIT license. See LICENSE for details.
